#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    [Gui.Design.DisplayName("RatioHL")]
    public class RatioHL : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int shortHL = 5; // Default setting for ShortHL
            private int longHL = 50; // Default setting for LongHL
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.Line, "Plot0"));
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
            Plot0.Set(((MAX(High, ShortHL)[0])-(MIN(Low, ShortHL)[0]))/((MAX(High, LongHL)[0])-(MIN(Low, LongHL)[0])));
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Description("")]
        [Category("Parameters")]
        public int ShortHL
        {
            get { return shortHL; }
            set { shortHL = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public int LongHL
        {
            get { return longHL; }
            set { longHL = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private RatioHL[] cacheRatioHL = null;

        private static RatioHL checkRatioHL = new RatioHL();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RatioHL RatioHL(int longHL, int shortHL)
        {
            return RatioHL(Input, longHL, shortHL);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RatioHL RatioHL(Data.IDataSeries input, int longHL, int shortHL)
        {
            checkRatioHL.LongHL = longHL;
            longHL = checkRatioHL.LongHL;
            checkRatioHL.ShortHL = shortHL;
            shortHL = checkRatioHL.ShortHL;

            if (cacheRatioHL != null)
                for (int idx = 0; idx < cacheRatioHL.Length; idx++)
                    if (cacheRatioHL[idx].LongHL == longHL && cacheRatioHL[idx].ShortHL == shortHL && cacheRatioHL[idx].EqualsInput(input))
                        return cacheRatioHL[idx];

            RatioHL indicator = new RatioHL();
            indicator.SetUp();
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.LongHL = longHL;
            indicator.ShortHL = shortHL;

            RatioHL[] tmp = new RatioHL[cacheRatioHL == null ? 1 : cacheRatioHL.Length + 1];
            if (cacheRatioHL != null)
                cacheRatioHL.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheRatioHL = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RatioHL RatioHL(int longHL, int shortHL)
        {
            return _indicator.RatioHL(Input, longHL, shortHL);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RatioHL RatioHL(Data.IDataSeries input, int longHL, int shortHL)
        {
            return _indicator.RatioHL(input, longHL, shortHL);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RatioHL RatioHL(int longHL, int shortHL)
        {
            return _indicator.RatioHL(Input, longHL, shortHL);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RatioHL RatioHL(Data.IDataSeries input, int longHL, int shortHL)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.RatioHL(input, longHL, shortHL);
        }

    }
}
#endregion
